@@ -129,11 +129,10 @@ class WebArea:
 
     Example::
 
-        class Area(WebArea):
-            body = Element("css:body")
-            first_div = Element("css:div")
-            links = Elements("css:a")
-
+        >>> class Area(WebArea):
+        ...    body = Element("css:body")
+        ...    first_div = Element("css:div")
+        ...    links = Elements("css:a")
         >>> area = Area(browser)
         >>> area.body
         <selenium.webdriver.remote.webelement.WebElement id="abcdef-1234">
@@ -349,11 +348,10 @@ class Page(WebArea):
 
     Example::
 
-        class QueryPage(Page):
-            main_title = TextElement("h1")
-            search = InputElement("input[name='query']")
-            button_validate = Element("button#validate")
-
+        >>> class QueryPage(Page):
+        ...     main_title = TextElement("h1")
+        ...     search = InputElement("input[name='query']")
+        ...     button_validate = Element("button#validate")
         >>> page = QueryPage(browser)
         >>> page.search = "python manen"
         >>> button_validate.click()
@@ -424,13 +422,12 @@ class Region(DomAccessor):
 
     Example::
 
-        class LoginPage(Page):
-            class FormRegion(Region):
-                email = InputElement("input#email")
-                password = InputElement("input#password")
-
-            form_region = FormRegion("div#form-container")
-
+        >>> from manen.page_object_model import Page, Region, InputElement, Action
+        >>> class LoginPage(Page):
+        ...     class FormRegion(Region):
+        ...         email = InputElement("input#email")
+        ...         password = InputElement("input#password")
+        ...     form_region = FormRegion("div#form-container")
         >>> page = LoginPage(browser)
         >>> page.form_region.email = "hello@manen.com"
         >>> page.form_region.password = "strong_password"
@@ -600,9 +597,10 @@ class InputElement(Element, post_processing=[lambda x: x.get_attribute("value")]
 
     Example::
 
-        class LoginPage(Page):
-            email = InputElement("input[type='email']")
-            password = InputElement("input[type='password']")
+        >>> from manen.page_object_model import Page, InputElement
+        >>> class LoginPage(Page):
+        ...     email = InputElement("input[type='email']")
+        ...     password = InputElement("input[type='password']")
 
         >>> from manen.page_object_model import Action
         >>> login_page = LoginPage(browser)
